/* 
simctrl_init.c
read simulation control flags for pointbgc simulation

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
Biome-BGCMuSo v6.1.
Original code: Copyright 2000, Peter E. Thornton
Numerical Terradynamic Simulation Group, The University of Montana, USA
Modified code: Copyright 2020, D. Hidy [dori.hidy@gmail.com]
Hungarian Academy of Sciences, Hungary
See the website of Biome-BGCMuSo at http://nimbus.elte.hu/bbgc/ for documentation, model executable and example input files.
*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
20.03.01 Galina Churkina added variable "sum" substituting  t1+t2+t3 in IF statement,
which gave an error.
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <time.h>
#include <math.h>
#include "ini.h"
#include "bgc_struct.h"
#include "pointbgc_struct.h"
#include "pointbgc_func.h"
#include "bgc_constants.h"



int simctrl_init(file init, epconst_struct* epc, control_struct* ctrl, planting_struct* PLT)
{
	int errflag=0;
	char key[] = "SIMULATION_CONTROL";
	char keyword[STRINGSIZE];


	
	/********************************************************************
	**                                                                 **
	** Begin reading initialization file block starting with keyword:  **
	** SOI_FILE                                                      ** 
	**                                                                 **
	********************************************************************/
	
	
	/* scan for the SOIL file keyword, exit if not next */
	if (!errflag && scan_value(init, keyword, 's'))
	{
		printf("ERROR reading keyword for control data\n");
		errflag=211;
	}
	if (!errflag && strcmp(keyword, key))
	{
		printf("Expecting keyword --> %s in file %s\n",key,init.name);
		errflag=211;
	}

	if (!errflag && scan_value(init, &epc->phenology_flag, 'i'))
	{
		printf("ERROR reading phenology flag, epc_init()\n");
		errflag=21101;
	}

	/* get flag of GSI flag */
	if (!errflag && scan_value(init, &epc->GSI_flag, 'i'))
	{
		printf("ERROR reading flag indicating usage of GSI file: epc_init()\n");
		errflag=21102;
	}
	
	if (!errflag && scan_value(init, &epc->transferGDD_flag, 'i'))
	{
		printf("ERROR reading transferGDD_flag, epc_init()\n");
		errflag=21103;
	}

	/* control of phenophase number */
	if (!errflag)
	{
		if (epc->transferGDD_flag && epc->n_emerg_phenophase < 1)
		{
			printf("ERROR in phenophase parametrization: if transferGDD_flag = 1 -> n_emerg_phenophase must be specified in EPC file()\n");
			errflag=2110301;
		}
	}

	/* temperature dependent q10 value */
	if (!errflag && scan_value(init, &epc->q10depend_flag, 'i'))
	{
		printf("ERROR reading q10depend_flag, epc_init()\n");
		errflag=21104;
	}
	
	/* acclimation */
	if (!errflag && scan_value(init, &epc->phtsyn_acclim_flag, 'i'))
	{
		printf("ERROR reading acclimation flag of photosynthesis, epc_init()\n");
		errflag=21105;
	}
	if (!errflag && scan_value(init, &epc->resp_acclim_flag, 'i'))
	{
		printf("ERROR reading acclimation flag of respiration, epc_init()\n");
		errflag=21106;
	}
	
	/* get flag of CO2 conductance reduction */
	if (!errflag && scan_value(init, &epc->CO2conduct_flag, 'i'))
	{
		printf("ERROR reading CO2conduct_flag, epc_init()\n");
		errflag=21107;
	}


	/* soil temperature calculation flag */
	if (!errflag && scan_value(init, &epc->STCM_flag, 'i'))
	{
		printf("ERROR reading soil temperature calculation flag: epc_init()\n");
		errflag=21108;
	}
	
	/* soil water calculation flag */
	if (!errflag && scan_value(init, &epc->SHCM_flag, 'i'))
	{
		printf("ERROR reading soil hydrological calculation method flag: epc_init()\n");
		errflag=21109;
	}

	/*  discretitaion level of VWC calculation simulation */
	if (!errflag && scan_value(init, &epc->discretlevel_Richards, 'i'))
	{
		printf("ERROR reading discretitaion level of VWC calculation: epc_init.c\n");
		errflag=21110;
	}

	/* control of discretlevel_Richards */
	if (!errflag && epc->SHCM_flag && epc->discretlevel_Richards > 0)
	{
		if (ctrl->onscreen) printf("WARNING: discretization level of soil hydr.calc. is used only with Richards-method, epc_init()\n");
	}


	/*  photosynthesis calculation method flag */
	if (!errflag && scan_value(init, &epc->photosynt_flag, 'i'))
	{
		printf("ERROR reading photosynthesis calculation method flag: epc_init.c\n");
		errflag=21111;
	}


	/*  evapotranspiration calculation method flag */
	if (!errflag && scan_value(init, &epc->evapotransp_flag, 'i'))
	{
		printf("ERROR reading evapotranspiration calculation method flag: epc_init.c\n");
		errflag=21112;
	}

	/* control: evapotransp_flag */
	if (!errflag && epc->evapotransp_flag) 
	{
		printf("ERROR: Priestley-Taylor photoynthesis method is not active yet in EPC file\n");
		printf("Please check EPC file and try it again\n");
		errflag=21112;
	}


	/*  radiation calculation method flag */
	if (!errflag && scan_value(init, &epc->radiation_flag, 'i'))
	{
		printf("ERROR reading radiation calculation method flag: epc_init.c\n");
		errflag=21113;
	}

	/*  soilstress calculation method flag */
	if (!errflag && scan_value(init, &epc->soilstress_flag, 'i'))
	{
		printf("ERROR reading soilstress calculation method flag: epc_init.c\n");
		errflag=21114;
	}

	/* control: in case of planting/harvesting, model-defined phenology is not possible: first day - planting day, last day - harvesting day */
	if (epc->phenology_flag == 1 && PLT->PLT_num) 
	{
		ctrl->prephen1_flag = 1;
		epc->phenology_flag = 0;
	}

	/* control: in case of user-defined phenology, GSI-method is not possible */
	if (epc->phenology_flag == 0 && epc->GSI_flag) 
	{
		ctrl->prephen2_flag = 1;
		epc->GSI_flag = 0;
	}
	



  return (errflag);
  
}